
.. _users-guide-index:

.. redirect-from:: /contents
.. redirect-from:: /users/explain


Using Matplotlib
================

.. grid:: 1 1 2 2

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/quick_start

        .. toctree::
            :maxdepth: 1

            faq.rst

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/figure/index

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/axes/index


    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/artists/index

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/configuration
            explain/customizing

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/colors/index

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/text/index

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/animations/index

    .. grid-item-card::
        :padding: 2

        .. toctree::
            :maxdepth: 2
            :includehidden:

            explain/toolkits/index


.. toctree::
    :hidden:

    getting_started/index
    ../install/index
    glossary
